# Badwulf 

## Minimal manager for Beowulf clusters and scientific data

The goal of *badwulf* is a provide a minimal command line interface for accessing and managing experimental data on scientific computing servers and Beowulf clusters.

This tool is __not__ intended to replace true cluster management and scheduling software for such as *Slurm*. Instead, *badwulf* is a lightweight package for simplying tasks such as:

- Connecting an port forwarded SSH session to a research server behind a login server

- Transfering files and directories between a local client and a research server

- Managing a simple repository of experimental data and metadata

- Searching experimental metadata for terms and keywords

- Syncing experimental data between a local client and a research server
